@@ -19,13 +19,18 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.redis_v1.services.cloud_redis import pagers
@@ -183,10 +188,10 @@ class CloudRedisAsyncClient:
 
     async def list_instances(
         self,
-        request: cloud_redis.ListInstancesRequest = None,
+        request: Union[cloud_redis.ListInstancesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListInstancesAsyncPager:
@@ -202,7 +207,7 @@ class CloudRedisAsyncClient:
         are aggregated.
 
         Args:
-            request (:class:`google.cloud.redis_v1.types.ListInstancesRequest`):
+            request (Union[google.cloud.redis_v1.types.ListInstancesRequest, dict]):
                 The request object. Request for
                 [ListInstances][google.cloud.redis.v1.CloudRedis.ListInstances].
             parent (:class:`str`):
@@ -274,17 +279,17 @@ class CloudRedisAsyncClient:
 
     async def get_instance(
         self,
-        request: cloud_redis.GetInstanceRequest = None,
+        request: Union[cloud_redis.GetInstanceRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloud_redis.Instance:
         r"""Gets the details of a specific Redis instance.
 
         Args:
-            request (:class:`google.cloud.redis_v1.types.GetInstanceRequest`):
+            request (Union[google.cloud.redis_v1.types.GetInstanceRequest, dict]):
                 The request object. Request for
                 [GetInstance][google.cloud.redis.v1.CloudRedis.GetInstance].
             name (:class:`str`):
@@ -344,12 +349,12 @@ class CloudRedisAsyncClient:
 
     async def create_instance(
         self,
-        request: cloud_redis.CreateInstanceRequest = None,
+        request: Union[cloud_redis.CreateInstanceRequest, dict] = None,
         *,
         parent: str = None,
         instance_id: str = None,
         instance: cloud_redis.Instance = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -369,7 +374,7 @@ class CloudRedisAsyncClient:
         hours, so there is no need to call DeleteOperation.
 
         Args:
-            request (:class:`google.cloud.redis_v1.types.CreateInstanceRequest`):
+            request (Union[google.cloud.redis_v1.types.CreateInstanceRequest, dict]):
                 The request object. Request for
                 [CreateInstance][google.cloud.redis.v1.CloudRedis.CreateInstance].
             parent (:class:`str`):
@@ -466,11 +471,11 @@ class CloudRedisAsyncClient:
 
     async def update_instance(
         self,
-        request: cloud_redis.UpdateInstanceRequest = None,
+        request: Union[cloud_redis.UpdateInstanceRequest, dict] = None,
         *,
         update_mask: field_mask_pb2.FieldMask = None,
         instance: cloud_redis.Instance = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -482,7 +487,7 @@ class CloudRedisAsyncClient:
         there is no need to call DeleteOperation.
 
         Args:
-            request (:class:`google.cloud.redis_v1.types.UpdateInstanceRequest`):
+            request (Union[google.cloud.redis_v1.types.UpdateInstanceRequest, dict]):
                 The request object. Request for
                 [UpdateInstance][google.cloud.redis.v1.CloudRedis.UpdateInstance].
             update_mask (:class:`google.protobuf.field_mask_pb2.FieldMask`):
@@ -495,6 +500,7 @@ class CloudRedisAsyncClient:
                 -  ``labels``
                 -  ``memorySizeGb``
                 -  ``redisConfig``
+                -  ``replica_count``
 
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -572,11 +578,11 @@ class CloudRedisAsyncClient:
 
     async def upgrade_instance(
         self,
-        request: cloud_redis.UpgradeInstanceRequest = None,
+        request: Union[cloud_redis.UpgradeInstanceRequest, dict] = None,
         *,
         name: str = None,
         redis_version: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -584,7 +590,7 @@ class CloudRedisAsyncClient:
         specified in the request.
 
         Args:
-            request (:class:`google.cloud.redis_v1.types.UpgradeInstanceRequest`):
+            request (Union[google.cloud.redis_v1.types.UpgradeInstanceRequest, dict]):
                 The request object. Request for
                 [UpgradeInstance][google.cloud.redis.v1.CloudRedis.UpgradeInstance].
             name (:class:`str`):
@@ -666,11 +672,11 @@ class CloudRedisAsyncClient:
 
     async def import_instance(
         self,
-        request: cloud_redis.ImportInstanceRequest = None,
+        request: Union[cloud_redis.ImportInstanceRequest, dict] = None,
         *,
         name: str = None,
         input_config: cloud_redis.InputConfig = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -685,7 +691,7 @@ class CloudRedisAsyncClient:
         few hours, so there is no need to call DeleteOperation.
 
         Args:
-            request (:class:`google.cloud.redis_v1.types.ImportInstanceRequest`):
+            request (Union[google.cloud.redis_v1.types.ImportInstanceRequest, dict]):
                 The request object. Request for
                 [Import][google.cloud.redis.v1.CloudRedis.ImportInstance].
             name (:class:`str`):
@@ -767,11 +773,11 @@ class CloudRedisAsyncClient:
 
     async def export_instance(
         self,
-        request: cloud_redis.ExportInstanceRequest = None,
+        request: Union[cloud_redis.ExportInstanceRequest, dict] = None,
         *,
         name: str = None,
         output_config: cloud_redis.OutputConfig = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -782,7 +788,7 @@ class CloudRedisAsyncClient:
         few hours, so there is no need to call DeleteOperation.
 
         Args:
-            request (:class:`google.cloud.redis_v1.types.ExportInstanceRequest`):
+            request (Union[google.cloud.redis_v1.types.ExportInstanceRequest, dict]):
                 The request object. Request for
                 [Export][google.cloud.redis.v1.CloudRedis.ExportInstance].
             name (:class:`str`):
@@ -864,20 +870,20 @@ class CloudRedisAsyncClient:
 
     async def failover_instance(
         self,
-        request: cloud_redis.FailoverInstanceRequest = None,
+        request: Union[cloud_redis.FailoverInstanceRequest, dict] = None,
         *,
         name: str = None,
         data_protection_mode: cloud_redis.FailoverInstanceRequest.DataProtectionMode = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
-        r"""Initiates a failover of the master node to current
+        r"""Initiates a failover of the primary node to current
         replica node for a specific STANDARD tier Cloud
         Memorystore for Redis instance.
 
         Args:
-            request (:class:`google.cloud.redis_v1.types.FailoverInstanceRequest`):
+            request (Union[google.cloud.redis_v1.types.FailoverInstanceRequest, dict]):
                 The request object. Request for
                 [Failover][google.cloud.redis.v1.CloudRedis.FailoverInstance].
             name (:class:`str`):
@@ -960,10 +966,10 @@ class CloudRedisAsyncClient:
 
     async def delete_instance(
         self,
-        request: cloud_redis.DeleteInstanceRequest = None,
+        request: Union[cloud_redis.DeleteInstanceRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -971,7 +977,7 @@ class CloudRedisAsyncClient:
         serving and data is deleted.
 
         Args:
-            request (:class:`google.cloud.redis_v1.types.DeleteInstanceRequest`):
+            request (Union[google.cloud.redis_v1.types.DeleteInstanceRequest, dict]):
                 The request object. Request for
                 [DeleteInstance][google.cloud.redis.v1.CloudRedis.DeleteInstance].
             name (:class:`str`):
