@@ -23,16 +23,24 @@ from .types.cloud_redis import ExportInstanceRequest
 from .types.cloud_redis import FailoverInstanceRequest
 from .types.cloud_redis import GcsDestination
 from .types.cloud_redis import GcsSource
+from .types.cloud_redis import GetInstanceAuthStringRequest
 from .types.cloud_redis import GetInstanceRequest
 from .types.cloud_redis import ImportInstanceRequest
 from .types.cloud_redis import InputConfig
 from .types.cloud_redis import Instance
+from .types.cloud_redis import InstanceAuthString
 from .types.cloud_redis import ListInstancesRequest
 from .types.cloud_redis import ListInstancesResponse
 from .types.cloud_redis import LocationMetadata
+from .types.cloud_redis import MaintenancePolicy
+from .types.cloud_redis import MaintenanceSchedule
+from .types.cloud_redis import NodeInfo
 from .types.cloud_redis import OutputConfig
+from .types.cloud_redis import RescheduleMaintenanceRequest
+from .types.cloud_redis import TlsCertificate
 from .types.cloud_redis import UpdateInstanceRequest
 from .types.cloud_redis import UpgradeInstanceRequest
+from .types.cloud_redis import WeeklyMaintenanceWindow
 from .types.cloud_redis import ZoneMetadata
 
 __all__ = (
@@ -44,15 +52,23 @@ __all__ = (
     "FailoverInstanceRequest",
     "GcsDestination",
     "GcsSource",
+    "GetInstanceAuthStringRequest",
     "GetInstanceRequest",
     "ImportInstanceRequest",
     "InputConfig",
     "Instance",
+    "InstanceAuthString",
     "ListInstancesRequest",
     "ListInstancesResponse",
     "LocationMetadata",
+    "MaintenancePolicy",
+    "MaintenanceSchedule",
+    "NodeInfo",
     "OutputConfig",
+    "RescheduleMaintenanceRequest",
+    "TlsCertificate",
     "UpdateInstanceRequest",
     "UpgradeInstanceRequest",
+    "WeeklyMaintenanceWindow",
     "ZoneMetadata",
 )
