@@ -19,13 +19,18 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.redis_v1beta1.services.cloud_redis import pagers
@@ -57,7 +62,7 @@ class CloudRedisAsyncClient:
     -  As such, Redis instances are resources of the form:
        ``/projects/{project_id}/locations/{location_id}/instances/{instance_id}``
 
-    Note that location_id must be refering to a GCP ``region``; for
+    Note that location_id must be referring to a GCP ``region``; for
     example:
 
     -  ``projects/redpepper-1290/locations/us-central1/instances/my-redis``
@@ -184,10 +189,10 @@ class CloudRedisAsyncClient:
 
     async def list_instances(
         self,
-        request: cloud_redis.ListInstancesRequest = None,
+        request: Union[cloud_redis.ListInstancesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListInstancesAsyncPager:
@@ -203,7 +208,7 @@ class CloudRedisAsyncClient:
         are aggregated.
 
         Args:
-            request (:class:`google.cloud.redis_v1beta1.types.ListInstancesRequest`):
+            request (Union[google.cloud.redis_v1beta1.types.ListInstancesRequest, dict]):
                 The request object. Request for
                 [ListInstances][google.cloud.redis.v1beta1.CloudRedis.ListInstances].
             parent (:class:`str`):
@@ -275,17 +280,17 @@ class CloudRedisAsyncClient:
 
     async def get_instance(
         self,
-        request: cloud_redis.GetInstanceRequest = None,
+        request: Union[cloud_redis.GetInstanceRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloud_redis.Instance:
         r"""Gets the details of a specific Redis instance.
 
         Args:
-            request (:class:`google.cloud.redis_v1beta1.types.GetInstanceRequest`):
+            request (Union[google.cloud.redis_v1beta1.types.GetInstanceRequest, dict]):
                 The request object. Request for
                 [GetInstance][google.cloud.redis.v1beta1.CloudRedis.GetInstance].
             name (:class:`str`):
@@ -343,14 +348,87 @@ class CloudRedisAsyncClient:
         # Done; return the response.
         return response
 
+    async def get_instance_auth_string(
+        self,
+        request: Union[cloud_redis.GetInstanceAuthStringRequest, dict] = None,
+        *,
+        name: str = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> cloud_redis.InstanceAuthString:
+        r"""Gets the AUTH string for a Redis instance. If AUTH is
+        not enabled for the instance the response will be empty.
+        This information is not included in the details returned
+        to GetInstance.
+
+        Args:
+            request (Union[google.cloud.redis_v1beta1.types.GetInstanceAuthStringRequest, dict]):
+                The request object. Request for
+                [GetInstanceAuthString][google.cloud.redis.v1beta1.CloudRedis.GetInstanceAuthString].
+            name (:class:`str`):
+                Required. Redis instance resource name using the form:
+                ``projects/{project_id}/locations/{location_id}/instances/{instance_id}``
+                where ``location_id`` refers to a GCP region.
+
+                This corresponds to the ``name`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.redis_v1beta1.types.InstanceAuthString:
+                Instance AUTH string details.
+        """
+        # Create or coerce a protobuf request object.
+        # Sanity check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        request = cloud_redis.GetInstanceAuthStringRequest(request)
+
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if name is not None:
+            request.name = name
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.get_instance_auth_string,
+            default_timeout=600.0,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Done; return the response.
+        return response
+
     async def create_instance(
         self,
-        request: cloud_redis.CreateInstanceRequest = None,
+        request: Union[cloud_redis.CreateInstanceRequest, dict] = None,
         *,
         parent: str = None,
         instance_id: str = None,
         instance: cloud_redis.Instance = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -362,15 +440,15 @@ class CloudRedisAsyncClient:
 
         The creation is executed asynchronously and callers may check
         the returned operation to track its progress. Once the operation
-        is completed the Redis instance will be fully functional.
-        Completed longrunning.Operation will contain the new instance
+        is completed the Redis instance will be fully functional. The
+        completed longrunning.Operation will contain the new instance
         object in the response field.
 
         The returned operation is automatically deleted after a few
         hours, so there is no need to call DeleteOperation.
 
         Args:
-            request (:class:`google.cloud.redis_v1beta1.types.CreateInstanceRequest`):
+            request (Union[google.cloud.redis_v1beta1.types.CreateInstanceRequest, dict]):
                 The request object. Request for
                 [CreateInstance][google.cloud.redis.v1beta1.CloudRedis.CreateInstance].
             parent (:class:`str`):
@@ -467,11 +545,11 @@ class CloudRedisAsyncClient:
 
     async def update_instance(
         self,
-        request: cloud_redis.UpdateInstanceRequest = None,
+        request: Union[cloud_redis.UpdateInstanceRequest, dict] = None,
         *,
         update_mask: field_mask_pb2.FieldMask = None,
         instance: cloud_redis.Instance = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -483,7 +561,7 @@ class CloudRedisAsyncClient:
         there is no need to call DeleteOperation.
 
         Args:
-            request (:class:`google.cloud.redis_v1beta1.types.UpdateInstanceRequest`):
+            request (Union[google.cloud.redis_v1beta1.types.UpdateInstanceRequest, dict]):
                 The request object. Request for
                 [UpdateInstance][google.cloud.redis.v1beta1.CloudRedis.UpdateInstance].
             update_mask (:class:`google.protobuf.field_mask_pb2.FieldMask`):
@@ -496,6 +574,7 @@ class CloudRedisAsyncClient:
                 -  ``labels``
                 -  ``memorySizeGb``
                 -  ``redisConfig``
+                -  ``replica_count``
 
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -573,11 +652,11 @@ class CloudRedisAsyncClient:
 
     async def upgrade_instance(
         self,
-        request: cloud_redis.UpgradeInstanceRequest = None,
+        request: Union[cloud_redis.UpgradeInstanceRequest, dict] = None,
         *,
         name: str = None,
         redis_version: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -585,7 +664,7 @@ class CloudRedisAsyncClient:
         specified in the request.
 
         Args:
-            request (:class:`google.cloud.redis_v1beta1.types.UpgradeInstanceRequest`):
+            request (Union[google.cloud.redis_v1beta1.types.UpgradeInstanceRequest, dict]):
                 The request object. Request for
                 [UpgradeInstance][google.cloud.redis.v1beta1.CloudRedis.UpgradeInstance].
             name (:class:`str`):
@@ -667,11 +746,11 @@ class CloudRedisAsyncClient:
 
     async def import_instance(
         self,
-        request: cloud_redis.ImportInstanceRequest = None,
+        request: Union[cloud_redis.ImportInstanceRequest, dict] = None,
         *,
         name: str = None,
         input_config: cloud_redis.InputConfig = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -686,7 +765,7 @@ class CloudRedisAsyncClient:
         few hours, so there is no need to call DeleteOperation.
 
         Args:
-            request (:class:`google.cloud.redis_v1beta1.types.ImportInstanceRequest`):
+            request (Union[google.cloud.redis_v1beta1.types.ImportInstanceRequest, dict]):
                 The request object. Request for
                 [Import][google.cloud.redis.v1beta1.CloudRedis.ImportInstance].
             name (:class:`str`):
@@ -768,11 +847,11 @@ class CloudRedisAsyncClient:
 
     async def export_instance(
         self,
-        request: cloud_redis.ExportInstanceRequest = None,
+        request: Union[cloud_redis.ExportInstanceRequest, dict] = None,
         *,
         name: str = None,
         output_config: cloud_redis.OutputConfig = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -783,7 +862,7 @@ class CloudRedisAsyncClient:
         few hours, so there is no need to call DeleteOperation.
 
         Args:
-            request (:class:`google.cloud.redis_v1beta1.types.ExportInstanceRequest`):
+            request (Union[google.cloud.redis_v1beta1.types.ExportInstanceRequest, dict]):
                 The request object. Request for
                 [Export][google.cloud.redis.v1beta1.CloudRedis.ExportInstance].
             name (:class:`str`):
@@ -865,20 +944,20 @@ class CloudRedisAsyncClient:
 
     async def failover_instance(
         self,
-        request: cloud_redis.FailoverInstanceRequest = None,
+        request: Union[cloud_redis.FailoverInstanceRequest, dict] = None,
         *,
         name: str = None,
         data_protection_mode: cloud_redis.FailoverInstanceRequest.DataProtectionMode = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
-        r"""Initiates a failover of the master node to current
+        r"""Initiates a failover of the primary node to current
         replica node for a specific STANDARD tier Cloud
         Memorystore for Redis instance.
 
         Args:
-            request (:class:`google.cloud.redis_v1beta1.types.FailoverInstanceRequest`):
+            request (Union[google.cloud.redis_v1beta1.types.FailoverInstanceRequest, dict]):
                 The request object. Request for
                 [Failover][google.cloud.redis.v1beta1.CloudRedis.FailoverInstance].
             name (:class:`str`):
@@ -961,10 +1040,10 @@ class CloudRedisAsyncClient:
 
     async def delete_instance(
         self,
-        request: cloud_redis.DeleteInstanceRequest = None,
+        request: Union[cloud_redis.DeleteInstanceRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -972,7 +1051,7 @@ class CloudRedisAsyncClient:
         serving and data is deleted.
 
         Args:
-            request (:class:`google.cloud.redis_v1beta1.types.DeleteInstanceRequest`):
+            request (Union[google.cloud.redis_v1beta1.types.DeleteInstanceRequest, dict]):
                 The request object. Request for
                 [DeleteInstance][google.cloud.redis.v1beta1.CloudRedis.DeleteInstance].
             name (:class:`str`):
@@ -1053,6 +1132,111 @@ class CloudRedisAsyncClient:
         # Done; return the response.
         return response
 
+    async def reschedule_maintenance(
+        self,
+        request: Union[cloud_redis.RescheduleMaintenanceRequest, dict] = None,
+        *,
+        name: str = None,
+        reschedule_type: cloud_redis.RescheduleMaintenanceRequest.RescheduleType = None,
+        schedule_time: timestamp_pb2.Timestamp = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operation_async.AsyncOperation:
+        r"""Reschedule maintenance for a given instance in a
+        given project and location.
+
+        Args:
+            request (Union[google.cloud.redis_v1beta1.types.RescheduleMaintenanceRequest, dict]):
+                The request object. Request for
+                [RescheduleMaintenance][google.cloud.redis.v1beta1.CloudRedis.RescheduleMaintenance].
+            name (:class:`str`):
+                Required. Redis instance resource name using the form:
+                ``projects/{project_id}/locations/{location_id}/instances/{instance_id}``
+                where ``location_id`` refers to a GCP region.
+
+                This corresponds to the ``name`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            reschedule_type (:class:`google.cloud.redis_v1beta1.types.RescheduleMaintenanceRequest.RescheduleType`):
+                Required. If reschedule type is SPECIFIC_TIME, must set
+                up schedule_time as well.
+
+                This corresponds to the ``reschedule_type`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            schedule_time (:class:`google.protobuf.timestamp_pb2.Timestamp`):
+                Optional. Timestamp when the maintenance shall be
+                rescheduled to if reschedule_type=SPECIFIC_TIME, in RFC
+                3339 format, for example ``2012-11-15T16:19:00.094Z``.
+
+                This corresponds to the ``schedule_time`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.api_core.operation_async.AsyncOperation:
+                An object representing a long-running operation.
+
+                The result type for the operation will be
+                :class:`google.cloud.redis_v1beta1.types.Instance` A
+                Google Cloud Redis instance.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Sanity check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([name, reschedule_type, schedule_time])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        request = cloud_redis.RescheduleMaintenanceRequest(request)
+
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if name is not None:
+            request.name = name
+        if reschedule_type is not None:
+            request.reschedule_type = reschedule_type
+        if schedule_time is not None:
+            request.schedule_time = schedule_time
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.reschedule_maintenance,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Wrap the response in an operation future.
+        response = operation_async.from_gapic(
+            response,
+            self._client._transport.operations_client,
+            cloud_redis.Instance,
+            metadata_type=any_pb2.Any,
+        )
+
+        # Done; return the response.
+        return response
+
     async def __aenter__(self):
         return self
 
