@@ -15,15 +15,14 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import packaging.version
 import pkg_resources
 
 import google.auth  # type: ignore
-import google.api_core  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
-from google.api_core import operations_v1  # type: ignore
+import google.api_core
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.api_core import operations_v1
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
@@ -37,15 +36,6 @@ try:
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
 
-try:
-    # google.auth.__version__ was added in 1.26.0
-    _GOOGLE_AUTH_VERSION = google.auth.__version__
-except AttributeError:
-    try:  # try pkg_resources if it is available
-        _GOOGLE_AUTH_VERSION = pkg_resources.get_distribution("google-auth").version
-    except pkg_resources.DistributionNotFound:  # pragma: NO COVER
-        _GOOGLE_AUTH_VERSION = None
-
 
 class CloudRedisTransport(abc.ABC):
     """Abstract transport class for CloudRedis."""
@@ -95,7 +85,7 @@ class CloudRedisTransport(abc.ABC):
             host += ":443"
         self._host = host
 
-        scopes_kwargs = self._get_scopes_kwargs(self._host, scopes)
+        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}
 
         # Save the scopes.
         self._scopes = scopes
@@ -111,7 +101,6 @@ class CloudRedisTransport(abc.ABC):
             credentials, _ = google.auth.load_credentials_from_file(
                 credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
             )
-
         elif credentials is None:
             credentials, _ = google.auth.default(
                 **scopes_kwargs, quota_project_id=quota_project_id
@@ -128,29 +117,6 @@ class CloudRedisTransport(abc.ABC):
         # Save the credentials.
         self._credentials = credentials
 
-    # TODO(busunkim): This method is in the base transport
-    # to avoid duplicating code across the transport classes. These functions
-    # should be deleted once the minimum required versions of google-auth is increased.
-
-    # TODO: Remove this function once google-auth >= 1.25.0 is required
-    @classmethod
-    def _get_scopes_kwargs(
-        cls, host: str, scopes: Optional[Sequence[str]]
-    ) -> Dict[str, Optional[Sequence[str]]]:
-        """Returns scopes kwargs to pass to google-auth methods depending on the google-auth version"""
-
-        scopes_kwargs = {}
-
-        if _GOOGLE_AUTH_VERSION and (
-            packaging.version.parse(_GOOGLE_AUTH_VERSION)
-            >= packaging.version.parse("1.25.0")
-        ):
-            scopes_kwargs = {"scopes": scopes, "default_scopes": cls.AUTH_SCOPES}
-        else:
-            scopes_kwargs = {"scopes": scopes or cls.AUTH_SCOPES}
-
-        return scopes_kwargs
-
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
@@ -160,6 +126,11 @@ class CloudRedisTransport(abc.ABC):
             self.get_instance: gapic_v1.method.wrap_method(
                 self.get_instance, default_timeout=600.0, client_info=client_info,
             ),
+            self.get_instance_auth_string: gapic_v1.method.wrap_method(
+                self.get_instance_auth_string,
+                default_timeout=600.0,
+                client_info=client_info,
+            ),
             self.create_instance: gapic_v1.method.wrap_method(
                 self.create_instance, default_timeout=600.0, client_info=client_info,
             ),
@@ -181,6 +152,11 @@ class CloudRedisTransport(abc.ABC):
             self.delete_instance: gapic_v1.method.wrap_method(
                 self.delete_instance, default_timeout=600.0, client_info=client_info,
             ),
+            self.reschedule_maintenance: gapic_v1.method.wrap_method(
+                self.reschedule_maintenance,
+                default_timeout=None,
+                client_info=client_info,
+            ),
         }
 
     def close(self):
@@ -193,7 +169,7 @@ class CloudRedisTransport(abc.ABC):
         raise NotImplementedError()
 
     @property
-    def operations_client(self) -> operations_v1.OperationsClient:
+    def operations_client(self):
         """Return the client designed to process long-running operations."""
         raise NotImplementedError()
 
@@ -218,6 +194,17 @@ class CloudRedisTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def get_instance_auth_string(
+        self,
+    ) -> Callable[
+        [cloud_redis.GetInstanceAuthStringRequest],
+        Union[
+            cloud_redis.InstanceAuthString, Awaitable[cloud_redis.InstanceAuthString]
+        ],
+    ]:
+        raise NotImplementedError()
+
     @property
     def create_instance(
         self,
@@ -281,5 +268,14 @@ class CloudRedisTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def reschedule_maintenance(
+        self,
+    ) -> Callable[
+        [cloud_redis.RescheduleMaintenanceRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
 
 __all__ = ("CloudRedisTransport",)
