@@ -16,12 +16,11 @@
 import warnings
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import grpc_helpers_async  # type: ignore
-from google.api_core import operations_v1  # type: ignore
+from google.api_core import gapic_v1
+from google.api_core import grpc_helpers_async
+from google.api_core import operations_v1
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
@@ -52,7 +51,7 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
     -  As such, Redis instances are resources of the form:
        ``/projects/{project_id}/locations/{location_id}/instances/{instance_id}``
 
-    Note that location_id must be refering to a GCP ``region``; for
+    Note that location_id must be referring to a GCP ``region``; for
     example:
 
     -  ``projects/redpepper-1290/locations/us-central1/instances/my-redis``
@@ -179,7 +178,7 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
         self._grpc_channel = None
         self._ssl_channel_credentials = ssl_channel_credentials
         self._stubs: Dict[str, Callable] = {}
-        self._operations_client = None
+        self._operations_client: Optional[operations_v1.OperationsAsyncClient] = None
 
         if api_mtls_endpoint:
             warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
@@ -330,6 +329,38 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
             )
         return self._stubs["get_instance"]
 
+    @property
+    def get_instance_auth_string(
+        self,
+    ) -> Callable[
+        [cloud_redis.GetInstanceAuthStringRequest],
+        Awaitable[cloud_redis.InstanceAuthString],
+    ]:
+        r"""Return a callable for the get instance auth string method over gRPC.
+
+        Gets the AUTH string for a Redis instance. If AUTH is
+        not enabled for the instance the response will be empty.
+        This information is not included in the details returned
+        to GetInstance.
+
+        Returns:
+            Callable[[~.GetInstanceAuthStringRequest],
+                    Awaitable[~.InstanceAuthString]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "get_instance_auth_string" not in self._stubs:
+            self._stubs["get_instance_auth_string"] = self.grpc_channel.unary_unary(
+                "/google.cloud.redis.v1beta1.CloudRedis/GetInstanceAuthString",
+                request_serializer=cloud_redis.GetInstanceAuthStringRequest.serialize,
+                response_deserializer=cloud_redis.InstanceAuthString.deserialize,
+            )
+        return self._stubs["get_instance_auth_string"]
+
     @property
     def create_instance(
         self,
@@ -346,8 +377,8 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
 
         The creation is executed asynchronously and callers may check
         the returned operation to track its progress. Once the operation
-        is completed the Redis instance will be fully functional.
-        Completed longrunning.Operation will contain the new instance
+        is completed the Redis instance will be fully functional. The
+        completed longrunning.Operation will contain the new instance
         object in the response field.
 
         The returned operation is automatically deleted after a few
@@ -509,7 +540,7 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
     ]:
         r"""Return a callable for the failover instance method over gRPC.
 
-        Initiates a failover of the master node to current
+        Initiates a failover of the primary node to current
         replica node for a specific STANDARD tier Cloud
         Memorystore for Redis instance.
 
@@ -560,6 +591,35 @@ class CloudRedisGrpcAsyncIOTransport(CloudRedisTransport):
             )
         return self._stubs["delete_instance"]
 
+    @property
+    def reschedule_maintenance(
+        self,
+    ) -> Callable[
+        [cloud_redis.RescheduleMaintenanceRequest], Awaitable[operations_pb2.Operation]
+    ]:
+        r"""Return a callable for the reschedule maintenance method over gRPC.
+
+        Reschedule maintenance for a given instance in a
+        given project and location.
+
+        Returns:
+            Callable[[~.RescheduleMaintenanceRequest],
+                    Awaitable[~.Operation]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "reschedule_maintenance" not in self._stubs:
+            self._stubs["reschedule_maintenance"] = self.grpc_channel.unary_unary(
+                "/google.cloud.redis.v1beta1.CloudRedis/RescheduleMaintenance",
+                request_serializer=cloud_redis.RescheduleMaintenanceRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["reschedule_maintenance"]
+
     def close(self):
         return self.grpc_channel.close()
 
