@@ -20,16 +20,24 @@ from .cloud_redis import (
     FailoverInstanceRequest,
     GcsDestination,
     GcsSource,
+    GetInstanceAuthStringRequest,
     GetInstanceRequest,
     ImportInstanceRequest,
     InputConfig,
     Instance,
+    InstanceAuthString,
     ListInstancesRequest,
     ListInstancesResponse,
     LocationMetadata,
+    MaintenancePolicy,
+    MaintenanceSchedule,
+    NodeInfo,
     OutputConfig,
+    RescheduleMaintenanceRequest,
+    TlsCertificate,
     UpdateInstanceRequest,
     UpgradeInstanceRequest,
+    WeeklyMaintenanceWindow,
     ZoneMetadata,
 )
 
@@ -40,15 +48,23 @@ __all__ = (
     "FailoverInstanceRequest",
     "GcsDestination",
     "GcsSource",
+    "GetInstanceAuthStringRequest",
     "GetInstanceRequest",
     "ImportInstanceRequest",
     "InputConfig",
     "Instance",
+    "InstanceAuthString",
     "ListInstancesRequest",
     "ListInstancesResponse",
     "LocationMetadata",
+    "MaintenancePolicy",
+    "MaintenanceSchedule",
+    "NodeInfo",
     "OutputConfig",
+    "RescheduleMaintenanceRequest",
+    "TlsCertificate",
     "UpdateInstanceRequest",
     "UpgradeInstanceRequest",
+    "WeeklyMaintenanceWindow",
     "ZoneMetadata",
 )
