@@ -15,17 +15,27 @@
 #
 import proto  # type: ignore
 
+from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
+from google.type import dayofweek_pb2  # type: ignore
+from google.type import timeofday_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
     package="google.cloud.redis.v1beta1",
     manifest={
+        "NodeInfo",
         "Instance",
+        "RescheduleMaintenanceRequest",
+        "MaintenancePolicy",
+        "WeeklyMaintenanceWindow",
+        "MaintenanceSchedule",
         "ListInstancesRequest",
         "ListInstancesResponse",
         "GetInstanceRequest",
+        "GetInstanceAuthStringRequest",
+        "InstanceAuthString",
         "CreateInstanceRequest",
         "UpdateInstanceRequest",
         "UpgradeInstanceRequest",
@@ -39,10 +49,26 @@ __protobuf__ = proto.module(
         "FailoverInstanceRequest",
         "LocationMetadata",
         "ZoneMetadata",
+        "TlsCertificate",
     },
 )
 
 
+class NodeInfo(proto.Message):
+    r"""Node specific properties.
+
+    Attributes:
+        id (str):
+            Output only. Node identifying string. e.g.
+            'node-0', 'node-1'
+        zone (str):
+            Output only. Location of the node.
+    """
+
+    id = proto.Field(proto.STRING, number=1,)
+    zone = proto.Field(proto.STRING, number=2,)
+
+
 class Instance(proto.Message):
     r"""A Google Cloud Redis instance.
 
@@ -68,19 +94,21 @@ class Instance(proto.Message):
             Resource labels to represent user provided
             metadata
         location_id (str):
-            Optional. The zone where the instance will be provisioned.
-            If not provided, the service will choose a zone for the
-            instance. For STANDARD_HA tier, instances will be created
-            across two zones for protection against zonal failures. If
-            [alternative_location_id][google.cloud.redis.v1beta1.Instance.alternative_location_id]
-            is also provided, it must be different from
-            [location_id][google.cloud.redis.v1beta1.Instance.location_id].
+            Optional. The zone where the instance will be
+            provisioned. If not provided, the service will
+            choose a zone from the specified region for the
+            instance. For standard tier, additional nodes
+            will be added across multiple zones for
+            protection against zonal failures. If specified,
+            at least one node will be provisioned in this
+            zone.
         alternative_location_id (str):
-            Optional. Only applicable to STANDARD_HA tier which protects
-            the instance against zonal failures by provisioning it
-            across two zones. If provided, it must be a different zone
-            from the one provided in
-            [location_id][google.cloud.redis.v1beta1.Instance.location_id].
+            Optional. If specified, at least one node will be
+            provisioned in this zone in addition to the zone specified
+            in location_id. Only applicable to standard tier. If
+            provided, it must be a different zone from the one provided
+            in [location_id]. Additional nodes beyond the first 2 will
+            be placed in zones selected by the service.
         redis_version (str):
             Optional. The version of Redis software. If not provided,
             latest supported version will be used. Currently, the
@@ -89,32 +117,29 @@ class Instance(proto.Message):
             -  ``REDIS_3_2`` for Redis 3.2 compatibility
             -  ``REDIS_4_0`` for Redis 4.0 compatibility (default)
             -  ``REDIS_5_0`` for Redis 5.0 compatibility
+            -  ``REDIS_6_X`` for Redis 6.x compatibility
         reserved_ip_range (str):
-            Optional. The CIDR range of internal
-            addresses that are reserved for this instance.
-            If not provided, the service will choose an
-            unused /29 block, for example, 10.0.0.0/29 or
-            192.168.0.0/29. Ranges must be unique and non-
-            overlapping with existing subnets in an
-            authorized network.
+            Optional. For DIRECT_PEERING mode, the CIDR range of
+            internal addresses that are reserved for this instance.
+            Range must be unique and non-overlapping with existing
+            subnets in an authorized network. For PRIVATE_SERVICE_ACCESS
+            mode, the name of one allocated IP address ranges associated
+            with this private service access connection. If not
+            provided, the service will choose an unused /29 block, for
+            example, 10.0.0.0/29 or 192.168.0.0/29. For
+            READ_REPLICAS_ENABLED the default block size is /28.
         host (str):
             Output only. Hostname or IP address of the
-            exposed Redis endpoint used by clients to
+            exposed Redis endpoint used by  clients to
             connect to the service.
         port (int):
             Output only. The port number of the exposed
             Redis endpoint.
         current_location_id (str):
-            Output only. The current zone where the Redis endpoint is
-            placed. For Basic Tier instances, this will always be the
-            same as the
-            [location_id][google.cloud.redis.v1beta1.Instance.location_id]
-            provided by the user at creation time. For Standard Tier
-            instances, this can be either
-            [location_id][google.cloud.redis.v1beta1.Instance.location_id]
-            or
-            [alternative_location_id][google.cloud.redis.v1beta1.Instance.alternative_location_id]
-            and can change after a failover event.
+            Output only. The current zone where the Redis primary node
+            is located. In basic tier, this will always be the same as
+            [location_id]. In standard tier, this can be the zone of any
+            node in the instance.
         create_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The time the instance was
             created.
@@ -161,9 +186,50 @@ class Instance(proto.Message):
             change over time for a given instance so should be checked
             before each import/export operation.
         connect_mode (google.cloud.redis_v1beta1.types.Instance.ConnectMode):
-            Optional. The connect mode of Redis instance. If not
-            provided, default one will be used. Current default:
-            DIRECT_PEERING.
+            Optional. The network connect mode of the Redis instance. If
+            not provided, the connect mode defaults to DIRECT_PEERING.
+        auth_enabled (bool):
+            Optional. Indicates whether OSS Redis AUTH is
+            enabled for the instance. If set to "true" AUTH
+            is enabled on the instance. Default value is
+            "false" meaning AUTH is disabled.
+        server_ca_certs (Sequence[google.cloud.redis_v1beta1.types.TlsCertificate]):
+            Output only. List of server CA certificates
+            for the instance.
+        transit_encryption_mode (google.cloud.redis_v1beta1.types.Instance.TransitEncryptionMode):
+            Optional. The TLS mode of the Redis instance.
+            If not provided, TLS is disabled for the
+            instance.
+        maintenance_policy (google.cloud.redis_v1beta1.types.MaintenancePolicy):
+            Optional. The maintenance policy for the
+            instance. If not provided, maintenance events
+            can be performed at any time.
+        maintenance_schedule (google.cloud.redis_v1beta1.types.MaintenanceSchedule):
+            Output only. Date and time of upcoming
+            maintenance events which have been scheduled.
+        replica_count (int):
+            Optional. The number of replica nodes. The valid range for
+            the Standard Tier with read replicas enabled is [1-5] and
+            defaults to 2. If read replicas are not enabled for a
+            Standard Tier instance, the only valid value is 1 and the
+            default is 1. The valid value for basic tier is 0 and the
+            default is also 0.
+        nodes (Sequence[google.cloud.redis_v1beta1.types.NodeInfo]):
+            Output only. Info per node.
+        read_endpoint (str):
+            Output only. Hostname or IP address of the
+            exposed readonly Redis endpoint. Standard tier
+            only. Targets all healthy replica nodes in
+            instance. Replication is asynchronous and
+            replica nodes will exhibit some lag behind the
+            primary. Write requests must target 'host'.
+        read_endpoint_port (int):
+            Output only. The port number of the exposed
+            readonly redis endpoint. Standard tier only.
+            Write requests should target 'port'.
+        read_replicas_mode (google.cloud.redis_v1beta1.types.Instance.ReadReplicasMode):
+            Optional. Read replica mode. Can only be
+            specified when trying to create the instance.
     """
 
     class State(proto.Enum):
@@ -190,6 +256,18 @@ class Instance(proto.Message):
         DIRECT_PEERING = 1
         PRIVATE_SERVICE_ACCESS = 2
 
+    class TransitEncryptionMode(proto.Enum):
+        r"""Available TLS modes."""
+        TRANSIT_ENCRYPTION_MODE_UNSPECIFIED = 0
+        SERVER_AUTHENTICATION = 1
+        DISABLED = 2
+
+    class ReadReplicasMode(proto.Enum):
+        r"""Read replicas mode."""
+        READ_REPLICAS_MODE_UNSPECIFIED = 0
+        READ_REPLICAS_DISABLED = 1
+        READ_REPLICAS_ENABLED = 2
+
     name = proto.Field(proto.STRING, number=1,)
     display_name = proto.Field(proto.STRING, number=2,)
     labels = proto.MapField(proto.STRING, proto.STRING, number=3,)
@@ -211,6 +289,133 @@ class Instance(proto.Message):
     authorized_network = proto.Field(proto.STRING, number=20,)
     persistence_iam_identity = proto.Field(proto.STRING, number=21,)
     connect_mode = proto.Field(proto.ENUM, number=22, enum=ConnectMode,)
+    auth_enabled = proto.Field(proto.BOOL, number=23,)
+    server_ca_certs = proto.RepeatedField(
+        proto.MESSAGE, number=25, message="TlsCertificate",
+    )
+    transit_encryption_mode = proto.Field(
+        proto.ENUM, number=26, enum=TransitEncryptionMode,
+    )
+    maintenance_policy = proto.Field(
+        proto.MESSAGE, number=27, message="MaintenancePolicy",
+    )
+    maintenance_schedule = proto.Field(
+        proto.MESSAGE, number=28, message="MaintenanceSchedule",
+    )
+    replica_count = proto.Field(proto.INT32, number=31,)
+    nodes = proto.RepeatedField(proto.MESSAGE, number=32, message="NodeInfo",)
+    read_endpoint = proto.Field(proto.STRING, number=33,)
+    read_endpoint_port = proto.Field(proto.INT32, number=34,)
+    read_replicas_mode = proto.Field(proto.ENUM, number=35, enum=ReadReplicasMode,)
+
+
+class RescheduleMaintenanceRequest(proto.Message):
+    r"""Request for
+    [RescheduleMaintenance][google.cloud.redis.v1beta1.CloudRedis.RescheduleMaintenance].
+
+    Attributes:
+        name (str):
+            Required. Redis instance resource name using the form:
+            ``projects/{project_id}/locations/{location_id}/instances/{instance_id}``
+            where ``location_id`` refers to a GCP region.
+        reschedule_type (google.cloud.redis_v1beta1.types.RescheduleMaintenanceRequest.RescheduleType):
+            Required. If reschedule type is SPECIFIC_TIME, must set up
+            schedule_time as well.
+        schedule_time (google.protobuf.timestamp_pb2.Timestamp):
+            Optional. Timestamp when the maintenance shall be
+            rescheduled to if reschedule_type=SPECIFIC_TIME, in RFC 3339
+            format, for example ``2012-11-15T16:19:00.094Z``.
+    """
+
+    class RescheduleType(proto.Enum):
+        r"""Reschedule options."""
+        RESCHEDULE_TYPE_UNSPECIFIED = 0
+        IMMEDIATE = 1
+        NEXT_AVAILABLE_WINDOW = 2
+        SPECIFIC_TIME = 3
+
+    name = proto.Field(proto.STRING, number=1,)
+    reschedule_type = proto.Field(proto.ENUM, number=2, enum=RescheduleType,)
+    schedule_time = proto.Field(
+        proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,
+    )
+
+
+class MaintenancePolicy(proto.Message):
+    r"""Maintenance policy for an instance.
+
+    Attributes:
+        create_time (google.protobuf.timestamp_pb2.Timestamp):
+            Output only. The time when the policy was
+            created.
+        update_time (google.protobuf.timestamp_pb2.Timestamp):
+            Output only. The time when the policy was
+            last updated.
+        description (str):
+            Optional. Description of what this policy is for.
+            Create/Update methods return INVALID_ARGUMENT if the length
+            is greater than 512.
+        weekly_maintenance_window (Sequence[google.cloud.redis_v1beta1.types.WeeklyMaintenanceWindow]):
+            Optional. Maintenance window that is applied to resources
+            covered by this policy. Minimum 1. For the current version,
+            the maximum number of weekly_window is expected to be one.
+    """
+
+    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
+    update_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
+    description = proto.Field(proto.STRING, number=3,)
+    weekly_maintenance_window = proto.RepeatedField(
+        proto.MESSAGE, number=4, message="WeeklyMaintenanceWindow",
+    )
+
+
+class WeeklyMaintenanceWindow(proto.Message):
+    r"""Time window in which disruptive maintenance updates occur.
+    Non-disruptive updates can occur inside or outside this window.
+
+    Attributes:
+        day (google.type.dayofweek_pb2.DayOfWeek):
+            Required. The day of week that maintenance
+            updates occur.
+        start_time (google.type.timeofday_pb2.TimeOfDay):
+            Required. Start time of the window in UTC
+            time.
+        duration (google.protobuf.duration_pb2.Duration):
+            Output only. Duration of the maintenance
+            window. The current window is fixed at 1 hour.
+    """
+
+    day = proto.Field(proto.ENUM, number=1, enum=dayofweek_pb2.DayOfWeek,)
+    start_time = proto.Field(proto.MESSAGE, number=2, message=timeofday_pb2.TimeOfDay,)
+    duration = proto.Field(proto.MESSAGE, number=3, message=duration_pb2.Duration,)
+
+
+class MaintenanceSchedule(proto.Message):
+    r"""Upcoming maintenance schedule. If no maintenance is
+    scheduled, fields are not populated.
+
+    Attributes:
+        start_time (google.protobuf.timestamp_pb2.Timestamp):
+            Output only. The start time of any upcoming
+            scheduled maintenance for this instance.
+        end_time (google.protobuf.timestamp_pb2.Timestamp):
+            Output only. The end time of any upcoming
+            scheduled maintenance for this instance.
+        can_reschedule (bool):
+            If the scheduled maintenance can be
+            rescheduled, default is true.
+        schedule_deadline_time (google.protobuf.timestamp_pb2.Timestamp):
+            Output only. The deadline that the
+            maintenance schedule start time can not go
+            beyond, including reschedule.
+    """
+
+    start_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
+    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
+    can_reschedule = proto.Field(proto.BOOL, number=3,)
+    schedule_deadline_time = proto.Field(
+        proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,
+    )
 
 
 class ListInstancesRequest(proto.Message):
@@ -254,9 +459,9 @@ class ListInstancesResponse(proto.Message):
             If the ``location_id`` in the parent field of the request is
             "-", all regions available to the project are queried, and
             the results aggregated. If in such an aggregated query a
-            location is unavailable, a dummy Redis entry is included in
-            the response with the ``name`` field set to a value of the
-            form
+            location is unavailable, a placeholder Redis entry is
+            included in the response with the ``name`` field set to a
+            value of the form
             ``projects/{project_id}/locations/{location_id}/instances/``-
             and the ``status`` field set to ERROR and ``status_message``
             field set to "location not available for ListInstances".
@@ -291,6 +496,31 @@ class GetInstanceRequest(proto.Message):
     name = proto.Field(proto.STRING, number=1,)
 
 
+class GetInstanceAuthStringRequest(proto.Message):
+    r"""Request for
+    [GetInstanceAuthString][google.cloud.redis.v1beta1.CloudRedis.GetInstanceAuthString].
+
+    Attributes:
+        name (str):
+            Required. Redis instance resource name using the form:
+            ``projects/{project_id}/locations/{location_id}/instances/{instance_id}``
+            where ``location_id`` refers to a GCP region.
+    """
+
+    name = proto.Field(proto.STRING, number=1,)
+
+
+class InstanceAuthString(proto.Message):
+    r"""Instance AUTH string details.
+
+    Attributes:
+        auth_string (str):
+            AUTH string set on the instance.
+    """
+
+    auth_string = proto.Field(proto.STRING, number=1,)
+
+
 class CreateInstanceRequest(proto.Message):
     r"""Request for
     [CreateInstance][google.cloud.redis.v1beta1.CloudRedis.CreateInstance].
@@ -334,6 +564,7 @@ class UpdateInstanceRequest(proto.Message):
             -  ``labels``
             -  ``memorySizeGb``
             -  ``redisConfig``
+            -  ``replica_count``
         instance (google.cloud.redis_v1beta1.types.Instance):
             Required. Update description. Only fields specified in
             update_mask are updated.
@@ -392,10 +623,14 @@ class GcsSource(proto.Message):
 class InputConfig(proto.Message):
     r"""The input content
 
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         gcs_source (google.cloud.redis_v1beta1.types.GcsSource):
             Google Cloud Storage location where input
             content is located.
+
+            This field is a member of `oneof`_ ``source``.
     """
 
     gcs_source = proto.Field(
@@ -436,10 +671,14 @@ class GcsDestination(proto.Message):
 class OutputConfig(proto.Message):
     r"""The output content
 
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         gcs_destination (google.cloud.redis_v1beta1.types.GcsDestination):
             Google Cloud Storage destination for output
             content.
+
+            This field is a member of `oneof`_ ``destination``.
     """
 
     gcs_destination = proto.Field(
@@ -518,4 +757,32 @@ class ZoneMetadata(proto.Message):
     """
 
 
+class TlsCertificate(proto.Message):
+    r"""TlsCertificate Resource
+
+    Attributes:
+        serial_number (str):
+            Serial number, as extracted from the
+            certificate.
+        cert (str):
+            PEM representation.
+        create_time (google.protobuf.timestamp_pb2.Timestamp):
+            Output only. The time when the certificate was created in
+            `RFC 3339 <https://tools.ietf.org/html/rfc3339>`__ format,
+            for example ``2020-05-18T00:00:00.094Z``.
+        expire_time (google.protobuf.timestamp_pb2.Timestamp):
+            Output only. The time when the certificate expires in `RFC
+            3339 <https://tools.ietf.org/html/rfc3339>`__ format, for
+            example ``2020-05-18T00:00:00.094Z``.
+        sha1_fingerprint (str):
+            Sha1 Fingerprint of the certificate.
+    """
+
+    serial_number = proto.Field(proto.STRING, number=1,)
+    cert = proto.Field(proto.STRING, number=2,)
+    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
+    expire_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
+    sha1_fingerprint = proto.Field(proto.STRING, number=5,)
+
+
 __all__ = tuple(sorted(__protobuf__.manifest))
